@@ -1,31 +1,41 @@
 #include "vctrs.h"
 #include "decl/assert-decl.h"
 
-void vec_assert(r_obj* x,
-                r_ssize size,
-                struct vctrs_arg* arg,
-                struct r_lazy call) {
-  vec_check_vector(x, arg, call);
+r_obj* ffi_obj_check_vector(r_obj* x, r_obj* frame) {
+  struct r_lazy call = { .x = r_syms.call, .env = frame };
+  struct r_lazy arg_lazy = { .x = r_syms.arg, .env = frame };
+  struct vctrs_arg arg = new_lazy_arg(&arg_lazy);
 
-  if (size != -1) {
-    // `size == -1` makes no assertion about size
-    vec_check_size(x, size, arg, call);
+  obj_check_vector(x, &arg, call);
+
+  return r_null;
+}
+
+void obj_check_vector(r_obj* x,
+                      struct vctrs_arg* arg,
+                      struct r_lazy call) {
+  if (!obj_is_vector(x)) {
+    stop_scalar_type(x, arg, call);
   }
 }
 
-void vec_check_vector(r_obj* x,
-                      struct vctrs_arg* arg,
-                      struct r_lazy call) {
-  if (!vec_is_vector(x)) {
-    stop_scalar_type(x, arg, call);
-  }
+r_obj* ffi_vec_check_size(r_obj* x, r_obj* ffi_size, r_obj* frame) {
+  struct r_lazy call = { .x = r_syms.call, .env = frame };
+  struct r_lazy arg_lazy = { .x = r_syms.arg, .env = frame };
+  struct vctrs_arg arg = new_lazy_arg(&arg_lazy);
+
+  const r_ssize size = r_arg_as_ssize(ffi_size, "size");
+
+  vec_check_size(x, size, &arg, call);
+
+  return r_null;
 }
 
 void vec_check_size(r_obj* x,
                     r_ssize size,
                     struct vctrs_arg* arg,
                     struct r_lazy call) {
-  r_ssize x_size = vec_size_3(x, arg, call);
+  const r_ssize x_size = vec_size_3(x, arg, call);
 
   if (x_size != size) {
     stop_assert_size(x_size, size, arg, call);
@@ -50,14 +60,14 @@ r_obj* ffi_check_list(r_obj* x, r_obj* frame) {
   struct r_lazy arg_data = { .x = syms.arg, .env = frame };
   struct vctrs_arg arg = new_lazy_arg(&arg_data);
 
-  vec_check_list(x, &arg, call);
+  obj_check_list(x, &arg, call);
   return r_null;
 }
 
-void vec_check_list(r_obj* x,
+void obj_check_list(r_obj* x,
                     struct vctrs_arg* arg,
                     struct r_lazy call) {
-  if (!vec_is_list(x)) {
+  if (!obj_is_list(x)) {
     stop_non_list_type(x, arg, call);
   }
 }
@@ -65,7 +75,7 @@ void vec_check_list(r_obj* x,
 
 r_obj* ffi_list_check_all_vectors(r_obj* x, r_obj* frame) {
   // This is an internal error
-  vec_check_list(x, vec_args.x, (struct r_lazy) {.x = frame, .env = r_null });
+  obj_check_list(x, vec_args.x, (struct r_lazy) {.x = frame, .env = r_null });
 
   struct r_lazy call = { .x = r_syms.call, .env = frame };
   struct r_lazy arg_caller_data = { .x = syms.arg, .env = frame };
@@ -79,7 +89,7 @@ r_obj* ffi_list_check_all_vectors(r_obj* x, r_obj* frame) {
   r_obj* const * v_x = r_list_cbegin(x);
 
   for (; i < n; ++i) {
-    vec_check_vector(v_x[i], arg, call);
+    obj_check_vector(v_x[i], arg, call);
   }
 
   FREE(1);
@@ -88,7 +98,7 @@ r_obj* ffi_list_check_all_vectors(r_obj* x, r_obj* frame) {
 
 r_obj* ffi_list_check_all_size(r_obj* xs, r_obj* ffi_size, r_obj* frame) {
   // This is an internal error
-  vec_check_list(xs, vec_args.x, (struct r_lazy) {.x = frame, .env = r_null });
+  obj_check_list(xs, vec_args.x, (struct r_lazy) {.x = frame, .env = r_null });
 
   struct r_lazy arg_lazy = { .x = syms.arg, .env = frame };
   struct vctrs_arg arg = new_lazy_arg(&arg_lazy);
